@@ -1,10 +1,7 @@
-use {Connection, Result};
+use crate::{Connection, Result};
 
-/// Old name for `LoadExtensionGuard`. `SqliteLoadExtensionGuard` is deprecated.
-#[deprecated(since = "0.6.0", note = "Use LoadExtensionGuard instead")]
-pub type SqliteLoadExtensionGuard<'conn> = LoadExtensionGuard<'conn>;
-
-/// RAII guard temporarily enabling SQLite extensions to be loaded.
+/// `feature = "load_extension"` RAII guard temporarily enabling SQLite
+/// extensions to be loaded.
 ///
 /// ## Example
 ///
@@ -12,7 +9,7 @@ pub type SqliteLoadExtensionGuard<'conn> = LoadExtensionGuard<'conn>;
 /// # use rusqlite::{Connection, Result, LoadExtensionGuard};
 /// # use std::path::{Path};
 /// fn load_my_extension(conn: &Connection) -> Result<()> {
-///     let _guard = try!(LoadExtensionGuard::new(conn));
+///     let _guard = LoadExtensionGuard::new(conn)?;
 ///
 ///     conn.load_extension(Path::new("my_sqlite_extension"), None)
 /// }
@@ -21,18 +18,20 @@ pub struct LoadExtensionGuard<'conn> {
     conn: &'conn Connection,
 }
 
-impl<'conn> LoadExtensionGuard<'conn> {
+impl LoadExtensionGuard<'_> {
     /// Attempt to enable loading extensions. Loading extensions will be
     /// disabled when this guard goes out of scope. Cannot be meaningfully
     /// nested.
-    pub fn new(conn: &Connection) -> Result<LoadExtensionGuard> {
+    #[inline]
+    pub fn new(conn: &Connection) -> Result<LoadExtensionGuard<'_>> {
         conn.load_extension_enable()
             .map(|_| LoadExtensionGuard { conn })
     }
 }
 
 #[allow(unused_must_use)]
-impl<'conn> Drop for LoadExtensionGuard<'conn> {
+impl Drop for LoadExtensionGuard<'_> {
+    #[inline]
     fn drop(&mut self) {
         self.conn.load_extension_disable();
     }
